@@ -14,7 +14,7 @@
 #  limitations under the License.
 ##
 
-labkey.deleteRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, toDelete) 
+labkey.deleteRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, toDelete, provenanceParams=NULL)
 {  
     baseUrl=labkey.getBaseUrl(baseUrl)
 
@@ -34,7 +34,12 @@ labkey.deleteRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, t
     toDelete <- convertFactorsToStrings(toDelete);
     nrows <- nrow(toDelete)
     ncols <- ncol(toDelete)
-    p1 <- toJSON(list(schemaName=schemaName, queryName=queryName, apiVersion=8.3), auto_unbox=TRUE)
+
+    params <- list(schemaName=schemaName, queryName=queryName, apiVersion=8.3)
+    if (!missing(provenanceParams))
+        params$provenance = provenanceParams
+
+    p1 <- toJSON(params, auto_unbox=TRUE)
     cnames <- colnames(toDelete)
     p3 <- NULL
     for(j in 1:nrows)
